@@ -1,3 +1,4 @@
+import json
 import sys
 import io
 import subprocess
@@ -57,14 +58,17 @@ def shell_run(cmd):
     return lines
 
 
-def run_unit_tests(apps) -> (int, str):
+def run_unit_tests(config_file: str, apps: tuple) -> (int, str):
     old_stderr, old_stdout = sys.stderr, sys.stdout
     new_stdout = io.StringIO()
     sys.stdout, sys.stderr = new_stdout, new_stdout
     try:
-        test_runner = DiscoverRunner(keepdb=True)
-        failures = test_runner.run_tests(apps)
-        output = new_stdout.getvalue()
+        with open(config_file) as f:
+            test_options = json.loads(f.read())
+            apps = apps or tuple(test_options.get('apps', []))
+            test_runner = DiscoverRunner(**test_options)
+            failures = test_runner.run_tests(apps)
+            output = new_stdout.getvalue()
         sys.stderr, sys.stdout = old_stderr, old_stdout
     except Exception as e:
         sys.stderr, sys.stdout = old_stderr, old_stdout
